@@ -18,6 +18,13 @@ logger = logging.getLogger('gene')
 logger.setLevel(logging.DEBUG)
 logger.handlers = []
 
+logging.getLogger("boto3").setLevel(logging.INFO)
+logging.getLogger("botocore").setLevel(logging.INFO)
+logging.getLogger("urllib3").setLevel(logging.INFO)
+logging.getLogger("python_jsonschema_objects").setLevel(logging.INFO)
+logging.getLogger("biocommons.seqrepo.seqaliasdb.seqaliasdb").setLevel(logging.INFO)  # noqa: E501
+logging.getLogger("biocommons.seqrepo.fastadir.fastadir").setLevel(logging.INFO)  # noqa: E501
+
 if 'GENE_NORM_EB_PROD' in environ:
     ch = logging.StreamHandler()
     ch.setLevel(logging.INFO)
